# Table of Contents

- [it-component-modeling-guidelines](<./it-component-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [IT Component Modeling Guidelines](<./IT-Component-Modeling-Guidelines.md>)
  - [Definition](<./IT-Component-Modeling-Guidelines/Definition.md>)
  - [Description](<./IT-Component-Modeling-Guidelines/Description.md>)
  - [IT Component Fact Sheet Subtypes](<./IT-Component-Modeling-Guidelines/IT-Component-Fact-Sheet-Subtypes.md>)
  - [Guidelines and Best Practices](<./IT-Component-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [Antipatterns](<./IT-Component-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./IT-Component-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from IT Component Fact Sheet](<./IT-Component-Modeling-Guidelines/Insights-from-IT-Component-Fact-Sheet.md>)
  - [Scenarios for the AI Model Subtype](<./IT-Component-Modeling-Guidelines/Scenarios-for-the-AI-Model-Subtype.md>)
  - [Transitioning to the AI Model Fact Sheet Subtype](<./IT-Component-Modeling-Guidelines/Transitioning-to-the-AI-Model-Fact-Sheet-Subtype.md>)
  - [Related Information](<./IT-Component-Modeling-Guidelines/Related-Information.md>)
  - [Was this page helpful?](<./IT-Component-Modeling-Guidelines/Was-this-page-helpful.md>)
